==> haskell-refinery-0.3.0.0-65-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-refinery.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 refinery
version:              0.3.0.0
visibility:           public
id:                   refinery-0.3.0.0-5hX7VTdf4GDIQ5ghxQDRtW
key:                  refinery-0.3.0.0-5hX7VTdf4GDIQ5ghxQDRtW
license:              BSD-3-Clause
copyright:            2019 Reed Mullanix
maintainer:           reedmullanix@gmail.com
author:               Reed Mullanix
homepage:             https://github.com/totbwf/refinery#readme
synopsis:             Toolkit for building proof automation systems
description:
    Please see the README on GitHub at <https://github.com/githubuser/refinery#readme>

category:             Language
abi:                  347b427464d9b3682558fb6b47d0d8dd
exposed:              True
exposed-modules:
    Refinery.ProofState Refinery.Tactic Refinery.Tactic.Internal

hidden-modules:       Paths_refinery
import-dirs:          /usr/lib/ghc-8.10.4/site-local/refinery-0.3.0.0
library-dirs:         /usr/lib/ghc-8.10.4/site-local/refinery-0.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/refinery-0.3.0.0
hs-libraries:         HSrefinery-0.3.0.0-5hX7VTdf4GDIQ5ghxQDRtW
depends:
    base-4.14.1.0 exceptions-0.10.4
    logict-0.7.1.0-DfchI38pA636W1gyTUKGv4
    mmorph-1.1.5-35UKpZuDVOl8bcf8tICns3 mtl-2.2.2

haddock-interfaces:   /usr/share/doc/haskell-refinery/html/refinery.haddock
haddock-html:         /usr/share/doc/haskell-refinery/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-refinery-0.3.0.0-66-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-refinery.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 refinery
version:              0.3.0.0
visibility:           public
id:                   refinery-0.3.0.0-6JvUZwsmCrVAu9Jb3z8SlE
key:                  refinery-0.3.0.0-6JvUZwsmCrVAu9Jb3z8SlE
license:              BSD-3-Clause
copyright:            2019 Reed Mullanix
maintainer:           reedmullanix@gmail.com
author:               Reed Mullanix
homepage:             https://github.com/totbwf/refinery#readme
synopsis:             Toolkit for building proof automation systems
description:
    Please see the README on GitHub at <https://github.com/githubuser/refinery#readme>

category:             Language
abi:                  d12fadd68f1f99986597a3f499ad8da4
exposed:              True
exposed-modules:
    Refinery.ProofState Refinery.Tactic Refinery.Tactic.Internal

hidden-modules:       Paths_refinery
import-dirs:          /usr/lib/ghc-8.10.4/site-local/refinery-0.3.0.0
library-dirs:         /usr/lib/ghc-8.10.4/site-local/refinery-0.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/refinery-0.3.0.0
hs-libraries:         HSrefinery-0.3.0.0-6JvUZwsmCrVAu9Jb3z8SlE
depends:
    base-4.14.1.0 exceptions-0.10.4
    logict-0.7.1.0-HSGM0xBuBB6G9ch5iSaI9E
    mmorph-1.1.5-35UKpZuDVOl8bcf8tICns3 mtl-2.2.2

haddock-interfaces:   /usr/share/doc/haskell-refinery/html/refinery.haddock
haddock-html:         /usr/share/doc/haskell-refinery/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
